@@ -1,13 +1,14 @@
 # $File: //member/autrijus/Module-Install-RTx/lib/Module/Install/RTx.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 9316 $ $DateTime: 2003/12/15 05:03:39 $ vim: expandtab shiftwidth=4
+# $Revision: #10 $ $Change: 9652 $ $DateTime: 2004/01/10 13:48:42 $ vim: expandtab shiftwidth=4
 
 package Module::Install::RTx;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$Module::Install::RTx::VERSION = '0.01';
+$Module::Install::RTx::VERSION = '0.04';
 
 use strict;
 use FindBin;
+use File::Basename;
 
 sub RTx {
     my ($self, $name) = @_;
@@ -25,7 +26,7 @@ sub RTx {
         local @INC = (
             @INC,
             $ENV{RTHOME},
-            map {( "$_/rt3/lib", "$_/lib/rt3" )} grep $_, @prefixes
+            map {( "$_/rt3/lib", "$_/lib/rt3", "$_/lib" )} grep $_, @prefixes
         );
         until ( eval { require RT; $RT::LocalPath } ) {
             warn "Cannot find the location of RT.pm that defines \$RT::LocalPath.\n";
@@ -41,8 +42,14 @@ sub RTx {
     $RT::LocalHtmlPath	||= $RT::MasonComponentRoot;
 
     my %path;
+    my $with_subdirs = $ENV{WITH_SUBDIRS};
+    @ARGV = grep { /WITH_SUBDIRS=(.*)/ ? (($with_subdirs = $1), 0) : 1 } @ARGV;
+    my %subdirs = map { $_ => 1 } split(/\s*,\s*/, $with_subdirs);
+
     foreach (qw(bin etc html po sbin var)) {
-        #next unless -d "$FindBin::Bin/$_";
+        next unless -d "$FindBin::Bin/$_";
+        next if %subdirs and !$subdirs{$_};
+        $self->no_index( directory => $_ );
 
         no strict 'refs';
         my $varname = "RT::Local" . ucfirst($_) . "Path";
@@ -53,10 +60,28 @@ sub RTx {
     print "./$_\t=> $path{$_}\n" for sort keys %path;
     my $args = join(', ', map "q($_)", %path);
 
-    $self->postamble(<< ".");
+    my $postamble = << ".";
 install ::
-\t\$(NOECHO) \$(PERL) -I. -MExtUtils::Install -e \"install({$args})\"
+\t\$(NOECHO) \$(PERL) -MExtUtils::Install -e \"install({$args})\"
 .
+
+    if ($path{var} and -d $RT::MasonDataDir) {
+        my ($uid, $gid) = (stat($RT::MasonDataDir))[4, 5];
+        $postamble .= << ".";
+\t\$(NOECHO) chown -R $uid:$gid $path{var}
+.
+    }
+
+    $self->postamble("$postamble\n");
+
+    if (-e 'etc/initialdata') {
+        print "For first-time installation, type 'make initialize-database'.\n";
+        my $lib_path = dirname($INC{'RT.pm'});
+        $self->postamble(<< ".");
+initialize-database ::
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" "$RT::BasePath/sbin/rt-setup-database" --action=insert --datafile=etc/initialdata
+.
+    }
 }
 
 1;
@@ -67,6 +92,10 @@ __END__
 
 Module::Install::RTx - RT extension installer
 
+=head1 VERSION
+
+This document describes version 0.04 of PAR, released January 10, 2004.
+
 =head1 SYNOPSIS
 
 In the F<Makefile.PL> of the C<RTx-Foo> module:
@@ -106,13 +135,20 @@ C<Foo>, it becomes:
     ./sbin  => /opt/rt3/local/sbin
     ./var   => /opt/rt3/var/Foo
 
-The files will be installed with C<make install>.
+By default, all these subdirectories will be installed with C<make install>.
+you can override this by setting the C<WITH_SUBDIRS> environment variable to
+a comma-delimited subdirectory list, such as C<html,sbin>.
+
+Alternatively, you can also specify the list as a command-line option to
+C<Makefile.PL>, like this:
+
+    perl Makefile.PL WITH_SUBDIRS=sbin
 
 =head1 SEE ALSO
 
 L<Module::Install>
 
-<http://www.bestpractical.com/rt/>
+L<http://www.bestpractical.com/rt/>
 
 =head1 AUTHORS
 
@@ -120,7 +156,7 @@ Autrijus Tang <autrijus@autrijus.org>
 
 =head1 COPYRIGHT
 
-Copyright 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003, 2004 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
